from setuptools import setup
setup(name="wrs",
version="0.1",
description="Split string without eliminating delimeter",
long_description = "This is a function package split string string into list without removing delimeter from string, can accept more than one delimeter at once in format:  'Delimeter1 | Delimeter2 | Delimeter3 | ...' ",
author="Rao Hamza",
packages=['wrs'],
install_requires=[])


def wr_split(delimeters,text):
  sep,str = delimeters , text
  sep = sep.replace(" ","")
  List = sep.split("|")
  #print(sep,List)

  for i in List:
    replace = True
    while replace == True:
      index = str.find(i)
      str = str[:index] + '| ' + str[index:]
      str = str.replace(i, i.upper(),1)
      if i.lower() not in str:
        replace = False

  str = str.lower()
  text_list = str.split("| ", )

  return text_list
